<?php
/**
 * Demo Import
 * 
 * @since 1.0.0
 */

add_filter( 'neuron/admin/demo-importer/import_files', 'ellada_ocdi_import_files' );

add_action( 'neuron/admin/demo-import/after_import', 'ellada_ocdi_after_import_setup' );


if ( ! function_exists( 'ellada_ocdi_import_files' ) ) {
    /**
     * Demo Importer
     * 
     * Import the content, widgets and
     * the customizer settings via the
     * plugin one click demo importer.
     */
    function ellada_ocdi_import_files() {
        $revslider_external_path = 'https://neuronthemes.com/api/plugins/revslider.zip';

        $plugins = [
            'acf' => [
                'slug' => 'advanced-custom-fields',
                'path' => 'advanced-custom-fields/acf.php'
            ],
            'woocommerce' => [
                'slug' => 'woocommerce',
                'path' => 'woocommerce/woocommerce.php'
            ],
            'revslider' => [
                'slug' => 'revslider',
                'path' => 'revslider/revslider.php',
                'external_path' => $revslider_external_path,
            ],
            'pods' => [
                'slug' => 'pods',
                'path' => 'pods/init.php',
            ],
        ];

        return array(
            array(
                'import_file_name'           => esc_html__('Main Demo', 'ellada'),
                'categories'                 => [ 'Main Demo' ],
                'import_file_url'            => 'https://neuron-s3-bucket.s3.eu-central-1.amazonaws.com/ellada/content.xml',
                'import_preview_image_url'   => 'https://neuron-s3-bucket.s3.eu-central-1.amazonaws.com/ellada/screenshot.jpg',
                'import_customizer_file_url' => 'https://neuron-s3-bucket.s3.eu-central-1.amazonaws.com/ellada/customizer.dat',
                'revslider_path'             => 'https://neuron-s3-bucket.s3.eu-central-1.amazonaws.com/ellada/slider-1.zip',
                'import_widget_file_url'     => 'https://neuron-s3-bucket.s3.eu-central-1.amazonaws.com/ellada/widgets.json',
                'preview_url'                => 'https://neuronthemes.com/ellada/landing',
            ),
        );
    }
}

if ( ! function_exists( 'ellada_ocdi_after_import_setup' ) ) {
    /**
     * After Import Setup
     * 
     * Set the Classic Home Page as front
     * page and assign the menu to 
     * the main menu location.
     */
    function ellada_ocdi_after_import_setup($selected_import) {
        $front_page_id = get_page_by_title( 'Home' );

        if ( $front_page_id ) {
            update_option( 'page_on_front', $front_page_id->ID );
            update_option( 'show_on_front', 'page' );
        }	

        $blog_page_id = get_page_by_title( 'Blog' );

        if ( $blog_page_id ) {
            update_option( 'page_for_posts', $blog_page_id->ID );
        }

        // Revolution Slider
        if ( class_exists( 'RevSlider' ) ) {
            if ( isset( $selected_import['revslider_path'] ) && ! empty( $selected_import['revslider_path'] ) ) {
                $slider_path = $selected_import['revslider_path'];

                if ( ! empty( $slider_path ) ) {

                    if ( is_array( $slider_path ) ) {
                        foreach ( $slider_path as $slider => $value ) {
                            $upload = ellada_fetch_remote_file( $value );

                            $rev_import = new RevSliderSliderImport();

                            if ( ! empty( $upload['file'] && isset( $upload['file'] ) ) ) {
                                $rev_import->import_slider( false, $upload['file'] );
                            }
                        }
                    } else {
                        $upload = ellada_fetch_remote_file( $slider_path );

                        $rev_import = new RevSliderSliderImport();

                        if ( ! empty( $upload['file'] && isset( $upload['file'] ) ) ) {
                            $rev_import->import_slider( false, $upload['file'] );
                        }
                    }
                }
            }
        }
    }
}