<?php
/**
 * Neuron Functions
 * 
 * Bunch of functions which improve & help the theme
 * to work better and keep the code more organised.
 * 
 * @since 1.0.0
 */

/**
 * Open and close container tags
 * 
 * Simply opens and closes the container tags,
 * theme uses it and finds helpful on files
 * that does not contain html tags.
 * 
 * @since 1.0.0
 */
add_action( 'n-theme/open/container', 'ellada_open_container' );
add_action( 'n-theme/close/container', 'ellada_close_container' );

if ( ! function_exists( 'ellada_open_container' ) ) {
	function ellada_open_container( $custom_class = '' ) {
		if ( $custom_class ) {
			$class = $custom_class;
		} else {
			$class = 'n-container';
		}
	?>
		<div class="<?php echo esc_attr( $class ) ?>">
	<?php
	}
}

if ( ! function_exists( 'ellada_close_container' ) ) {
	function ellada_close_container() {
	?>
		</div>
	<?php
	}
}

if ( ! function_exists( 'ellada_pagination' ) ) {
	/**
	 * Default Pagination
	 * 
	 * Well organised pagination with numbers and arrows,
	 * theme uses it on blogs and portfolios.
	 */
	function ellada_pagination( $query = '' ) {
		global $paged;

		$ellada_range = 10;
		$ellada_pages = '';
		$ellada_showitems = ( $ellada_range * 2) + 1;

		if ( empty( $paged ) ) {
			if ( get_query_var( 'paged' ) ) {
				$paged = get_query_var( 'paged' );
			} elseif ( get_query_var( 'page' ) ) {
				$paged = get_query_var( 'page' );
			} else {
				$paged = 1;
			}
		}

		if ( $ellada_pages == '' ) {
			global $wp_query;
			if ( $query ) {
				$ellada_pages = $query->max_num_pages;
			} else {
				$ellada_pages = $wp_query->max_num_pages;
			}

			if ( ! $ellada_pages ) {
				$ellada_pages = 1;
			}
		}

		if ( 1 != $ellada_pages ) {
			echo "<div class='n-site-pagination'>";

			$ellada_prev_class = 'n-site-pagination__arrow';
			$ellada_next_class = 'n-site-pagination__arrow';
			if ( $paged <= 1 ) {
				$ellada_prev_class = 'n-site-pagination__arrow n-site-pagination__arrow--disabled';
			} 

			$link = "href=". esc_url( get_pagenum_link( $paged - 1 ) ) ."";

			if ( $paged == 1 ) {
				$link = '';
			}

			echo "<div class='". $ellada_prev_class ."'><a class=\"neurontheme-link\" ". $link ."><svg xmlns='http://www.w3.org/2000/svg' width='22' height='22' viewBox='0 0 24 24' fill='none' stroke-width='2' stroke-linecap='round' stroke-linejoin='round' class='feather feather-chevron-left'><polyline points='15 18 9 12 15 6'></polyline></svg></a></div>";

			echo "<ul class='n-site-pagination__numbers'>";
			for ( $i = 1; $i <= $ellada_pages; $i++ ) {
				if ( 1 != $ellada_pages && (!( $i >= $paged + $ellada_range + 1 || $i <= $paged - $ellada_range - 1) || $ellada_pages <= $ellada_showitems ) ) {
					if ( $paged == $i ) {
						echo "<li class=\"active\"><a>". $i ."</a></li>";
					} else {
						echo "<li><a href='". get_pagenum_link( $i) ."' class=\"inactive neurontheme-link\">". $i ."</a></li>";
					}
				}
			}

			$ellada_pages_float = intval( $ellada_pages );
			echo "</ul>";


			if ( $paged == $ellada_pages_float ) {
				$ellada_next_class = 'n-site-pagination__arrow n-site-pagination__arrow--disabled';
			}

			echo "<div class='". esc_attr( $ellada_next_class ) ."'><a class=\"neurontheme-link\" href='". esc_url( get_pagenum_link( $paged + 1) ) ."'><svg xmlns='http://www.w3.org/2000/svg' width='22' height='22' viewBox='0 0 24 24' fill='none' stroke-width='2' stroke-linecap='round' stroke-linejoin='round' class='feather feather-chevron-right'><polyline points='9 18 15 12 9 6'></polyline></svg></a></div>";

			echo "</div>\n";
		}
	}
}

/**
 * Modify wp_link_pages to show 
 */
add_filter( 'wp_link_pages_args', 'ellada_wp_link_pages_args_prevnext_add' );

if ( ! function_exists( 'ellada_wp_link_pages_args_prevnext_add' ) ) {
	function ellada_wp_link_pages_args_prevnext_add( $args ) {
		global $page, $numpages, $more, $pagenow;
		
		if ( ! $args['next_or_number'] == 'next_and_number' ) {
			return $args; 
		} 

		$args['next_or_number'] = 'number'; 

		if ( ! $more ) {
			return $args; 
		}
		return $args;
	}
}

add_action( 'wp_ajax_update_wordpress_option', 'ellada_update_wordpress_option' );
add_action( 'wp_ajax_nopriv_update_wordpress_option', 'ellada_update_wordpress_option' );

function ellada_update_wordpress_option() {
    $option = $_POST['option'];

	if ( ! empty( $option ) ) {

		if ( isset( $option['siteLogo'] ) && ! empty( $option['siteLogo'] ) ) {
			set_theme_mod( 'custom_logo', $option['siteLogo'] );
			update_option( 'custom_logo', $option['siteLogo'] );
			set_theme_mod( 'site_logo', $option['siteLogo'] );
		}

		if ( isset( $option['siteTitle'] ) && ! empty( $option['siteTitle'] ) ) {
			update_option( 'blogname', $option['siteTitle'] );
		}

		if ( isset( $option['siteTagline'] ) && ! empty( $option['siteTagline'] ) ) {
			update_option( 'blogdescription', $option['siteTagline'] );
		}
	}

    die();
}

add_action( 'wp_ajax_wizard_file_upload', 'ellada_file_upload_callback' );
add_action( 'wp_ajax_nopriv_wizard_file_upload', 'ellada_file_upload_callback' );

function ellada_file_upload_callback() {
	$arr_img_ext = array('image/png', 'image/jpeg', 'image/jpg', 'image/gif');

    if ( in_array( $_FILES['file']['type'], $arr_img_ext ) ) {
		// These files need to be included as dependencies when on the front end.
		require_once( ABSPATH . 'wp-admin/includes/image.php' );
		require_once( ABSPATH . 'wp-admin/includes/file.php' );
		require_once( ABSPATH . 'wp-admin/includes/media.php' );
			
		// Let WordPress handle the upload.
		// Remember, 'my_image_upload' is the name of our file input in our form above.
		$attachment_id = media_handle_upload( 'file', $_POST['post_id'] );
			
		if ( ! is_wp_error( $attachment_id ) ) {
			wp_send_json( $attachment_id );
		} 
    }

    wp_die();
}

/**
 * Fetch Remote URL
 * 
 * @since 1.0.0
 */
if ( ! function_exists( 'ellada_fetch_remote_file' ) ) {
	function ellada_fetch_remote_file( $url ) {
		// extract the file name and extension from the url
		$file_name = basename( $url );

		// get placeholder file in the upload dir with a unique, sanitized filename
		$upload = wp_upload_bits( $file_name, 0, '', get_the_date() );

		if ( $upload['error'] ) {
			return new WP_Error( 'upload_dir_error', $upload['error'] );
		}

		// fetch the remote url and write it to the placeholder file
		$response = wp_remote_get( $url, array(
			'stream' => true,
			'filename' => $upload['file'],
		) );

		// request failed
		if ( is_wp_error( $response ) ) {
			unlink( $upload['file'] );
			return $response;
		}

		$code = (int) wp_remote_retrieve_response_code( $response );

		// make sure the fetch was successful
		if ( $code !== 200 ) {
			unlink( $upload['file'] );
			return new WP_Error(
				'import_file_error',
				sprintf(
					__( 'Remote server returned %1$d %2$s for %3$s', 'ellada' ),
					$code,
					get_status_header_desc( $code ),
					$url
				)
			);
		}

		return $upload;
	}
}

/**
 * Extend Gallery
 * 
 * Add proofing and other
 * gallery options like 
 * downloading.
 * 
 * @since 1.0.0
 */
if ( did_action( 'elementor/loaded' ) ) {
	add_action( 'elementor/element/neuron-gallery/layout_section/before_section_end', 'ellada_extend_neuron_gallery_options', 10, 2 );
	add_action( 'elementor/element/neuron-gallery/filters_section/before_section_end', 'ellada_extend_neuron_filters_options', 10, 2 );
	add_action( 'elementor/element/neuron-gallery/filters_section/before_section_end', 'ellada_extend_neuron_filters_options', 10, 2 );
	add_action( 'elementor/element/neuron-gallery/filters_style_section/after_section_end', 'ellada_extend_neuron_proofing_style_options', 10, 2 );
	add_action( 'elementor/element/before_section_end', 'ellada_update_gallery_html_tag', 10, 3 );

	add_action( 'neuron/element/gallery/after_inner_start', 'ellada_add_link_overlay' , 10, 3 );
	add_action( 'neuron/element/gallery/before_item_start', 'ellada_gallery_add_item_class', 10, 3 );

	add_filter( 'neuron/element/gallery/image_details', 'ellada_extend_image_details', 10, 3 );
	add_filter( 'neuron/element/gallery/filters', 'ellada_add_proofing_filters', 10, 2 );
	add_filter( 'neuron/attachment/options', 'ellada_attachment_proofing_option' );

	add_action( 'wp_ajax_ellada_change_gallery_item_proofing', 'ellada_change_gallery_item_proofing' );
	add_action( 'wp_ajax_nopriv_ellada_change_gallery_item_proofing', 'ellada_change_gallery_item_proofing' );

}

if ( ! function_exists( 'ellada_extend_neuron_gallery_options' ) ) {
	function ellada_extend_neuron_gallery_options( $element, $args ) {
		$element->update_control(
			'gallery_type',
			[
				'options' => [
					'single' => esc_html__( 'Single', 'ellada' ),
					'multiple' => esc_html__( 'Multiple', 'ellada' ),
					'proofing' => esc_html__( 'Proofing', 'ellada' ),
				],
			]
		);

		$element->update_control(
			'gallery',
			[
				'conditions' => [
					'relation' => 'or',
					'terms' => [
						[
							'name' => 'gallery_type',
							'value' => 'single',
						],
						[
							'name' => 'gallery_type',
							'value' => 'proofing',
						],
						[
							'terms' => [
								[
									'name' => 'carousel',
									'operator' => '===',
									'value' => 'yes',
								],
							],
						],
					],
				],
			]
		);

		$element->update_control(
			'image_details',
			[
				'options' => [
					'title' => esc_html__( 'Title', 'ellada' ),
					'caption' => esc_html__( 'Caption', 'ellada' ),
					'description' => esc_html__( 'Description', 'ellada' ),
					'download' => esc_html__( 'Download', 'ellada' ),
					'proofing' => esc_html__( 'Proofing', 'ellada' ),
				],
			]
		);
	}
}

if ( ! function_exists( 'ellada_extend_neuron_filters_options' ) ) {
	function ellada_extend_neuron_filters_options( $element, $args ) {
		
		$element->update_control(
			'filters_section',
			[
				'condition' => [
					'gallery_type' => [ 'multiple', 'proofing' ],
					'carousel!' => 'yes'
				]
			]
		);
		
		$element->update_control(
			'filters_style',
			[
				'condition' => [
					'!gallery_type' => 'multiple',
				]
			]
		);

		$element->update_control(
			'filters_columns',
			[
				'condition' => [
					'!gallery_type' => 'multiple',
				]
			]
		);

		$element->update_control(
			'filters_prefix',
			[
				'condition' => [
					'!gallery_type' => 'multiple',
				]
			]
		);

		$element->update_control(
			'filters_close_click',
			[
				'condition' => [
					'!gallery_type' => 'multiple',
				]
			]
		);
	}
}

if ( ! function_exists( 'ellada_extend_neuron_proofing_style_options' ) ) {
	function ellada_extend_neuron_proofing_style_options( $element, $args ) {
		$element->start_controls_section( 
			'proofing_style_section', [ 
				'label' => esc_html__( 'Proofing', 'ellada' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [ 
					'image_details' => 'proofing',
				]
			] 
		);

		$element->add_control( 
			'proofing_color', [ 
				'label' => esc_html__( 'Proofing Color', 'ellada' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .m-neuron-gallery__image-detail--proofing svg path' => 'stroke: {{VALUE}}',
				],
			] 
		);

		$element->add_responsive_control( 
			'proofing_size', [ 
				'label' => esc_html__( 'Size', 'ellada' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px', 'rem', '%'],
				'selectors' => [
					'{{WRAPPER}} .m-neuron-gallery__image-detail--proofing' => 'font-size: {{SIZE}}{{UNIT}}',
				]
			] 
		);

		$element->add_responsive_control( 
			'proofing_x_position', [ 
				'label' => esc_html__( 'X Position', 'ellada' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
				'default' => [
					'unit' => '%'
				],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .m-neuron-gallery__image-detail--proofing' => 'right: {{SIZE}}{{UNIT}}',
				]
			] 
		);

		$element->add_responsive_control( 
			'proofing_y_position', [ 
				'label' => esc_html__( 'Y Position', 'ellada' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
				'default' => [
					'unit' => '%'
				],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .m-neuron-gallery__image-detail--proofing' => 'top: {{SIZE}}{{UNIT}}',
				]
			] 
		);


		$element->end_controls_section(); 

		$element->start_controls_section( 
			'download_style_section', [ 
				'label' => esc_html__( 'Download', 'ellada' ),
				'tab' => \Elementor\Controls_Manager::TAB_STYLE,
				'condition' => [ 
					'image_details' => 'download',
				]
			] 
		);

		$element->add_control( 
			'download_color', [ 
				'label' => esc_html__( 'Proofing Color', 'ellada' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .m-neuron-gallery__image-detail--download svg path' => 'stroke: {{VALUE}}',
				],
			] 
		);

		$element->add_responsive_control( 
			'download_size', [ 
				'label' => esc_html__( 'Size', 'ellada' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => ['px', 'rem', '%'],
				'selectors' => [
					'{{WRAPPER}} .m-neuron-gallery__image-detail--download' => 'font-size: {{SIZE}}{{UNIT}}',
				]
			] 
		);

		$element->add_responsive_control( 
			'download_x_position', [ 
				'label' => esc_html__( 'X Position', 'ellada' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
				'default' => [
					'unit' => '%'
				],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .m-neuron-gallery__image-detail--download' => 'right: {{SIZE}}{{UNIT}}',
				]
			] 
		);

		$element->add_responsive_control( 
			'download_y_position', [ 
				'label' => esc_html__( 'Y Position', 'ellada' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ '%' ],
				'default' => [
					'unit' => '%'
				],
				'range' => [
					'%' => [
						'min' => 0,
						'max' => 100,
						'step' => 1,
					],
				],
				'selectors' => [
					'{{WRAPPER}} .m-neuron-gallery__image-detail--download' => 'top: {{SIZE}}{{UNIT}}',
				]
			] 
		);

		$element->end_controls_section(); 
	}
}

if ( ! function_exists( 'ellada_add_proofing_filters' ) ) {
	function ellada_add_proofing_filters( $filters, $type ) {

		if ( $type == 'proofing' ) {
			$filters['approved'] = 'Approved';
			$filters['rejected'] = 'Rejected';
		}
		
		return $filters;
	}
}

if ( ! function_exists( 'ellada_extend_image_details' ) ) {
	function ellada_extend_image_details( $details, $gallery_attachment, $image_details ) {

		// Download
		if ( in_array( 'download', $image_details ) ) {
			$url = wp_get_attachment_image_src( $gallery_attachment->ID, 'full' );
	
			if ( ! empty( $url ) ) {
				$details['download'] = '<a href="'. $url[0] .'" download>
					<svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-download"><path d="M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4"></path><polyline points="7 10 12 15 17 10"></polyline><line x1="12" y1="15" x2="12" y2="3"></line></svg>					
				</a>';
			}
		}

		// Proofing
		if ( in_array( 'proofing', $image_details ) ) {
			$details['proofing'] = '<span class="m-neuron-gallery__image-detail--image-action-icon">
			<span class="m-neuron-gallery__image-detail--approve-icon">
				<svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-check">
					<polyline points="20 6 9 17 4 12"></polyline>
				</svg>
			</span>
			<span class="m-neuron-gallery__image-detail--reject-icon">
				<svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-x"><line x1="18" y1="6" x2="6" y2="18"></line><line x1="6" y1="6" x2="18" y2="18"></line></svg>
			</span>
			</span>';
		}

		return $details;
	}
}

// Update html tag to unclickable
if ( ! function_exists( 'ellada_update_gallery_html_tag' ) ) {
	function ellada_update_gallery_html_tag( $section, $section_id, $args ) {
		if ( $section->get_name() == 'neuron-gallery' && $section_id == 'layout_section' ){
			$section->update_control(
				'html_tag_overlay' ,
				[
					'default' => 'div'
				]
			);
		}
	}
}

// Add link for item click
if ( ! function_exists( 'ellada_add_link_overlay' ) ) {
	function ellada_add_link_overlay( $self, $id, $gallery_attachment ) {
		$url = wp_get_attachment_image_src( $id, 'full' );
		
		$self->remove_render_attribute( 'gallery_item_url_' . $id, 'class' );

		$external_url = get_post_meta( $gallery_attachment->ID, '_external_url', true );
		$should_print = $self->get_settings('lightbox') == 'yes' || ! empty( $external_url );

		if ( ! empty( $url ) && $should_print ) {
			echo '<a class="m-neuron-gallery__overlay--link" '. $self->get_render_attribute_string( 'gallery_item_url_' . $id ) .' target="_BLANK" href="'. esc_url( $url[0] ) .'"></a>';
		}
	}
}

// Attachment Option
if ( ! function_exists( 'ellada_attachment_proofing_option' ) ) {
	function ellada_attachment_proofing_option( $fields ) {

		$fields['neuron_proofing'] = [
			 'label'       => esc_html__( 'Proofing', 'ellada' ),
                'input'       => 'select',
                'options'     => [
                    '' => 'None',
                    'approved' => esc_html__( 'Approved', 'ellada' ),
                    'rejected' => esc_html__( 'Rejected', 'ellada' ),
                ],
                'default_value' => ''
		];
		
		return $fields;
	}
}


// Add Class the item
if ( ! function_exists( 'ellada_gallery_add_item_class' ) ) {
	function ellada_gallery_add_item_class( $self, $id, $gallery_attachment ) {

		$category = get_post_meta($gallery_attachment->ID, '_neuron_proofing', true);

		if ( $category ) {
		
			$self->add_render_attribute( 'gallery_item_url_' . $id,
			[
				'class' => $category
			]
			);
		}
	}
}

if ( ! function_exists( 'ellada_change_gallery_item_proofing' ) ) {
	function ellada_change_gallery_item_proofing() {
		if ( empty( $_POST['gallery_item_proofing'] ) ) {
			wp_send_json_error( __( 'Proofing Option is Missing', 'ellada' ) );
		}

		if ( isset( $_POST['gallery_item_proofing'] ) && ! empty( $_POST['gallery_item_proofing'] ) && isset( $_POST['gallery_item_state'] ) && ! empty( $_POST['gallery_item_state'] ) ) {
			update_post_meta( $_POST['gallery_item_proofing'], '_neuron_proofing', $_POST['gallery_item_state'] );
		}

		wp_die();
	}
}