<?php
/**
 * Cart Title
 * 
 * Hooks: woocommerce_before_cart_table
 * 
 * @since 1.0.0
 */
add_action( 'woocommerce_before_cart_table', 'ellada_cart_title' );

if ( ! function_exists( 'ellada_cart_title' ) ) {
    function ellada_cart_title() {
        echo '<h2>'. esc_html__( 'Cart', 'ellada' ) .'</h2>';
    }
}

/**
 * Wrap Checkout Totals
 * 
 * Hooks: woocommerce_checkout_before_order_review_heading, woocommerce_checkout_after_order_review
 * 
 * @since 1.0.0
 */
add_action( 'woocommerce_checkout_before_order_review_heading', 'ellada_checkout_before_totals' );
add_action( 'woocommerce_checkout_after_order_review', 'ellada_checkout_after_totals' );

if ( ! function_exists( 'ellada_checkout_before_totals' ) ) {
    function ellada_checkout_before_totals() {
        echo '<div class="n-checkout-totals">';
    }
}

if ( ! function_exists( 'ellada_checkout_after_totals' ) ) {
    function ellada_checkout_after_totals() {
        echo '</div>';
    }
}

/**
 * Product Thumbnail Sizes
 * 
 * Hooks: woocommerce_gallery_thumbnail_size
 * 
 * @since 1.0.0
 */
add_action( 'woocommerce_gallery_thumbnail_size', 'ellada_product_thumbnail_sizes' );

if ( ! function_exists( 'ellada_product_thumbnail_sizes' )  ) {
    function ellada_product_thumbnail_sizes() {
        return [ 300, 300 ];
    }
}


/**
 * Thumbnails in Grouped Product
 * 
 * Hooks: woocommerce_grouped_product_list_before_quantity
 * 
 * @since 1.0.0
 */
add_action( 'woocommerce_grouped_product_list_before_quantity', 'ellada_product_grouped_thumbnails' );

if ( ! function_exists( 'ellada_product_grouped_thumbnails' ) ) {
    function ellada_product_grouped_thumbnails( $product ) {
        $image_size = array( 120, 120 );
        $attachment_id = get_post_meta( $product->get_id(), '_thumbnail_id', true );
        $link = get_the_permalink( $product->get_id() );
        ?>
        <td class="woocommerce-grouped-product-list-item__thumb">
            <a href="<?php echo esc_url( $link ); ?>" > <?php echo wp_get_attachment_image( $attachment_id, $image_size ); ?> </a>
        </td>
        <?php
    }
}